@@ -92,7 +92,8 @@ class Witter():
         self.program = hildon.Program()
         self.program.__init__()
 
-        self.osso_c = osso.Context("witter", "0.2.0", False)
+        self.osso_c = osso.Context("witter", "0.2.1", False)
+        self.osso_rpc = osso.Rpc(self.osso_c)
         # set name of application: this shows in titlebar
         gtk.set_application_name("Witter")
         self.twitterUrlRoot = "https://twitter.com/"
@@ -1362,58 +1363,126 @@ class Witter():
 
 
     def FollowUser(self, widget, name, *args):
+        #strip out the @ which isn't really part of the username
+        name = name.replace("@", "")
         print "follow: " + name
 
-        post = urllib.urlencode({ 'screen_name' : name })
+        try:
 
-        #build the request with the url and our post data
-        req = urllib2.Request('http://twitter.com/friendships/create.json', post)
+            #if we have an access token, use oauth
+          #  if (self.access_token != ""):
+           #     print "using oauth to unfollow"
+            #    twitter = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.access_token)
+             #   if (self.user == ""):
+              #      self.user = twitter.GetUserInfo()
+#
+ #               data = twitter.CreateFriendship(name)
+  ##              note = osso.SystemNote(self.osso_c)
+    #            result = note.system_note_infoprint("Now following " + name)
 
-        auth_handler = urllib2.HTTPBasicAuthHandler()
-        #realm here is important. or at least it seemed to be
-        #this info is on the login box if you go to the url in a browser
+     #       else:
+                post = urllib.urlencode({ 'screen_name' : name })
 
-        auth_handler.add_password(realm='Twitter API',
-                          uri='http://twitter.com/friendships/create.json',
-                          user=self.username,
-                          passwd=self.password)
-        #we create an 'opener' object with our auth_handler
-        opener = urllib2.build_opener(auth_handler)
-        # ...and install it globally so it can be used with urlopen.
-        urllib2.install_opener(opener)
-        #switch on whether this is an refresh or a first download
+                #build the request with the url and our post data
+                req = urllib2.Request('http://twitter.com/friendships/create.json', post)
 
-        json = urllib2.urlopen(req)
-        #JSON is awesome stuff. we get given a long string of json encoded information
-        #which contains all the tweets, with lots of info, we decode to a json object
-        data = simplejson.loads(json.read())
-        print data
+                auth_handler = urllib2.HTTPBasicAuthHandler()
+                #realm here is important. or at least it seemed to be
+                #this info is on the login box if you go to the url in a browser
 
+                auth_handler.add_password(realm='Twitter API',
+                                  uri='http://twitter.com/friendships/create.json',
+                                  user=self.username,
+                                  passwd=self.password)
+                #we create an 'opener' object with our auth_handler
+                opener = urllib2.build_opener(auth_handler)
+                # ...and install it globally so it can be used with urlopen.
+                urllib2.install_opener(opener)
+                #switch on whether this is an refresh or a first download
+
+                json = urllib2.urlopen(req)
+                #JSON is awesome stuff. we get given a long string of json encoded information
+                #which contains all the tweets, with lots of info, we decode to a json object
+                data = simplejson.loads(json.read())
+                note = osso.SystemNote(self.osso_c)
+                result = note.system_note_infoprint("Now following " + name)
+        except IOError, e:
+            print "error"
+            msg = 'Error following ' + name + ' '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+            print msg
     def UnFollowUser(self, widget, name, *args):
+        #strip out the @ which isn't really part of the username
+        name = name.replace("@", "")
         print "unfollow : " + name
-        post = urllib.urlencode({ 'screen_name' : name })
 
-        #build the request with the url and our post data
-        req = urllib2.Request('http://twitter.com/friendships/destroy.json', post)
+        try:
+            #if we have an access token, use oauth
+      #      if (self.access_token != ""):
+       #         print "using oauth to unfollow"
+        #        twitter = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.access_token)
+         #       if (self.user == ""):
+         #           self.user = twitter.GetUserInfo()
+#
+ #               data = twitter.DestroyFriendship(name)
+  ##              note = osso.SystemNote(self.osso_c)
+ #               result = note.system_note_infoprint("Unfollowed " + name)
+#
+     #    else:
+            post = urllib.urlencode({ 'screen_name' : name })
+            #build the request with the url and our post data
+            req = urllib2.Request('http://twitter.com/friendships/destroy.json', post)
 
-        auth_handler = urllib2.HTTPBasicAuthHandler()
-        #realm here is important. or at least it seemed to be
-        #this info is on the login box if you go to the url in a browser
-        auth_handler.add_password(realm='Twitter API',
-                          uri='http://twitter.com/friendships/destroy.json',
-                          user=self.username,
-                          passwd=self.password)
-        #we create an 'opener' object with our auth_handler
-        opener = urllib2.build_opener(auth_handler)
-        # ...and install it globally so it can be used with urlopen.
-        urllib2.install_opener(opener)
-        #switch on whether this is an refresh or a first download
+            auth_handler = urllib2.HTTPBasicAuthHandler()
+            #realm here is important. or at least it seemed to be
+            #this info is on the login box if you go to the url in a browser
+            auth_handler.add_password(realm='Twitter API',
+                              uri='http://twitter.com/friendships/destroy.json',
+                              user=self.username,
+                              passwd=self.password)
+            #we create an 'opener' object with our auth_handler
+            opener = urllib2.build_opener(auth_handler)
+            # ...and install it globally so it can be used with urlopen.
+            urllib2.install_opener(opener)
+            #switch on whether this is an refresh or a first download
 
-        json = urllib2.urlopen(req)
-        #JSON is awesome stuff. we get given a long string of json encoded information
-        #which contains all the tweets, with lots of info, we decode to a json object
-        data = simplejson.loads(json.read())
-        print data
+            json = urllib2.urlopen(req)
+            #JSON is awesome stuff. we get given a long string of json encoded information
+            #which contains all the tweets, with lots of info, we decode to a json object
+            data = simplejson.loads(json.read())
+            note = osso.SystemNote(self.osso_c)
+            result = note.system_note_infoprint("Unfollowed " + name)
+        except IOError, e:
+            print "error"
+            msg = 'Error unfollowing ' + name + ' '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+            print msg
 
     def replyTo(self, widget, *args):
 	if (self.treeview.get_model() == self.searchliststore):
@@ -1467,7 +1536,8 @@ class Witter():
         #open a url in a browser
         if (self.maemo_ver == 5):
 	    print "opening browser - maemo5 style"
-            webbrowser.open_new(url)
+            #webbrowser.open_new(url)
+            self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (url,))
         else:
 	    print "opening browser - maemo4 style"
             webbrowser.open(url, context=self.osso_c)
@@ -1595,7 +1665,7 @@ class Witter():
              self.request_token = twitter.getRequestToken()
              authorization_url = twitter.getAuthorizationURL(self.request_token)
              print authorization_url
-             webbrowser.open_new(authorization_url)
+             self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (authorization_url,))
              note = hildon.Note("confirmation", self.window, "authorise with twitter...")
              note.set_button_texts("ok", "cancel")
              note.connect("response", self.gtk_widget_hide)
@@ -1798,7 +1868,7 @@ class Witter():
 
     def about(self, widget, *args):
 		dlg = gtk.AboutDialog()
-		dlg.set_version("0.2.0")
+		dlg.set_version("0.2.1")
 		dlg.set_name("Witter")
 		#"Marcus Wikstrm (logo)"
 		dlg.set_authors(["Daniel Would (programmer)", u"Marcus Wikström (logo)"])
